pub enum ControlMessage<ID> {
Create {
initial_members: Vec<ID>,
},
Update,
Remove {
removed: ID,
},
Add {
added: ID,
},
}Available on crate features
data_scheme only.Expand description
Message that should be broadcast to the group.
The control message must be distributed to the other group members through Authenticated Causal Broadcast, calling the process function on the recipient when they are delivered.
Variants