pub struct DcgkaState<ID, OP, PKI, DGM, KMG>where
ID: IdentityHandle,
OP: OperationId,
PKI: IdentityRegistry<ID, PKI::State> + PreKeyRegistry<ID, LongTermKeyBundle>,
DGM: GroupMembership<ID, OP>,
KMG: IdentityManager<KMG::State> + PreKeyManager,{
pub pki: PKI::State,
pub my_keys: KMG::State,
pub my_id: ID,
pub two_party: HashMap<ID, TwoPartyState<LongTermKeyBundle>>,
pub dgm: DGM::State,
}Available on crate features
data_scheme only.Expand description
Serializable state of “data encryption” DCGKA (for persistence).
Fields
pki: PKI::StatePublic Key Infrastructure (PKI). From here we retrieve the identity keys and long-term pre-key bundles for each member to do 2SM.
my_keys: KMG::StateOur own key manager state holding the secret parts for our own identity keys and published long-term pre-key bundles so we can do 2SM.
my_id: IDOur id which is used as a unique handle inside this group.
two_party: HashMap<ID, TwoPartyState<LongTermKeyBundle>>Handlers for each member to manage the “Two-Party Secure Messaging” (2SM) key-agreement protocol as specified in the paper.
dgm: DGM::StateDecentralised group membership (DGM) state.