pub enum GroupOutput<ID, OP, DGM, ORD>where
DGM: GroupMembership<ID, OP>,
ORD: Ordering<ID, OP, DGM>,{
Control(ORD::Message),
Application {
plaintext: Vec<u8>,
},
Removed,
}Available on crate features
data_scheme only.Expand description
Result from processing a remote message or calling a local group operation.
Variants
Control(ORD::Message)
Control message for group encryption which should be broadcast to all members of the group.
Application
Decrypted payload of message.
Removed
Signal that we’ve been removed from the group.