Module key_manager

Module key_manager 

Manager for our own secret key material.

Peers should automatically rotate their key bundles if the lifetime is close to expiring. It is recommended to do this in good time before the actual expiration date to allow others to receive it even when the network is unstable or peers are longer offline.

Structs

KeyManager
Key manager to maintain secret key material (like our identity key) and to generate signed public pre-key bundles.
KeyManagerState
Serializable state of key manager.
PreKeyBundle
Extended pre-key struct holding the public and secret parts and signature, authenticating the pre-key with an identity.
PreKeyBundlesState
Collection of all known, publishable pre-keys with their regarding secrets and signatures in this key manager. Offers a form of “garbage collection” to automatically remove expired pre-keys.

Enums

KeyManagerError