pub struct PreKeyBundlesState(/* private fields */);Expand description
Collection of all known, publishable pre-keys with their regarding secrets and signatures in this key manager. Offers a form of “garbage collection” to automatically remove expired pre-keys.
This can be serialized and independently stored from the identity secrets.