Module traits

Module traits 

Interfaces to integrate p2panda-encryption into custom data- and messaging types, group management- and ordering strategies.

Enums

ForwardSecureMessageContentmessage_scheme
GroupMessageContentdata_scheme

Traits

AckedGroupMembershipmessage_scheme
Decentralised group membership (DGM) algorithm with acknowledgements.
ForwardSecureGroupMessagemessage_scheme
Interface to express required information from messages following the “message encryption” protocol for groups.
ForwardSecureOrderingmessage_scheme
Ordering protocol for p2panda’s “message encryption” scheme. Extra care is required here, since the strong forward secrecy guarantees makes ordering more strict.
GroupMembershipdata_scheme
Decentralised group membership (DGM) algorithm.
GroupMessagedata_scheme
Interface to express required information from messages following the “data encryption” protocol for groups.
IdentityHandle
Handle to identify a group member.
IdentityManager
Manages our own identity secret.
IdentityRegistry
Manages public identity keys of other members.
KeyBundle
Key bundle holding data to establish a X3DH key-agreement.
OperationId
Identifier for each group membership operation.
Orderingdata_scheme
Ordering protocol for p2panda’s “data encryption” scheme.
PreKeyManager
Manages our own pre-key secrets to generate public key bundles.
PreKeyRegistry
Manages public key bundles of other members.