pub trait GroupMessage<ID, OP, DGM>where
DGM: GroupMembership<ID, OP>,{
// Required methods
fn id(&self) -> OP;
fn sender(&self) -> ID;
fn content(&self) -> GroupMessageContent<ID>;
fn direct_messages(&self) -> Vec<DirectMessage<ID, OP, DGM>>;
}Available on crate features
data_scheme only.Expand description
Interface to express required information from messages following the “data encryption” protocol for groups.
Applications implementing these traits should authenticate the original sender of each message.
Messages, except of the direct ones, need to be broadcast to the whole group.
Required Methods
Sourcefn content(&self) -> GroupMessageContent<ID>
fn content(&self) -> GroupMessageContent<ID>
Returns content of either a control- or application message.
Sourcefn direct_messages(&self) -> Vec<DirectMessage<ID, OP, DGM>>
fn direct_messages(&self) -> Vec<DirectMessage<ID, OP, DGM>>
Returns optional list of direct messages.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<DGM> GroupMessage<usize, MessageId, DGM> for TestMessage<DGM>
Available on crate features
test_utils only.