IdentityHandle

Trait IdentityHandle 

pub trait IdentityHandle:
    Copy
    + Debug
    + PartialEq
    + Eq
    + StdHash { }
Handle to identify a group member.

Note that this needs to be unique within a group, can be a username, number or preferably a long byte string.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IdentityHandle for &str

Available on crate features test_utils only.
Source

impl IdentityHandle for VerifyingKey

Source

impl IdentityHandle for usize

Available on crate features test_utils only.

Implementors